@@ -1,23 +1,3 @@
-/* -copyright-
-#-# 
-#-# xsnow: let it snow on your desktop
-#-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020,2021,2022,2023,2024 Willem Vermin
-#-# 
-#-# This program is free software: you can redistribute it and/or modify
-#-# it under the terms of the GNU General Public License as published by
-#-# the Free Software Foundation, either version 3 of the License, or
-#-# (at your option) any later version.
-#-# 
-#-# This program is distributed in the hope that it will be useful,
-#-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-#-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#-# GNU General Public License for more details.
-#-# 
-#-# You should have received a copy of the GNU General Public License
-#-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#-# 
- */
 /*
    This file is part of ``kdtree'', a library for working with kd-trees.
    Copyright (C) 2007-2011 John Tsiombikas <nuclear@member.fsf.org>
@@ -65,7 +45,6 @@
 #include <math.h>
 #include <assert.h>
 #include "kdtree.h"
-#include "safe_malloc.h"
 
 #if defined(WIN32) || defined(__WIN32__)
 #include <malloc.h>
