@@ -1,23 +1,23 @@
 /* 
  -copyright-
-#-# 
-#-# xsnow: let it snow on your desktop
-#-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020,2021,2022,2023,2024 Willem Vermin
-#-# 
-#-# This program is free software: you can redistribute it and/or modify
-#-# it under the terms of the GNU General Public License as published by
-#-# the Free Software Foundation, either version 3 of the License, or
-#-# (at your option) any later version.
-#-# 
-#-# This program is distributed in the hope that it will be useful,
-#-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-#-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#-# GNU General Public License for more details.
-#-# 
-#-# You should have received a copy of the GNU General Public License
-#-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#-# 
+# xsnow: let it snow on your desktop
+# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
+#              2019,2020,2021,2022,2023,2024 Willem Vermin
+# 
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# 
+#-endcopyright-
 */
 
 #include <pthread.h>
@@ -27,6 +27,7 @@
 #include <X11/Intrinsic.h>
 #include <X11/extensions/Xinerama.h>
 #include <ctype.h>
+#include <assert.h>
 
 #include "xsnow-constants.h"
 
@@ -402,6 +403,7 @@ void UpdateFallenSnowRegions()
    }
    // nf+1: prevent allocation of zero bytes
    long int *toremove = (long int *)malloc(sizeof(*toremove)*(nf+1));
+   assert(toremove);
    int ntoremove = 0;
    fsnow = global.FsnowFirst;
    while(fsnow)
@@ -649,6 +651,7 @@ void SetBackground()
    P("pad: %d %d\n",XBitmapPad(display),depth);
 
    unsigned char *pixels1 = (unsigned char*)malloc(w*h*4*sizeof(unsigned char));
+   assert(pixels1);
    // https://gnome.pages.gitlab.gnome.org/gdk-pixbuf/gdk-pixbuf/class.Pixbuf.html
    //
 
